@@ -172,11 +172,9 @@ def dsq_main():
         colored = True
         if not supports_color() :
             colored = False
-        if os.environ.get("force_ansicolor","").lower() in ["true","yes","y","1"] :
+        if os.environ.get("force_ansicolor","") in ["true","yes","y","1"] :
             colored = True
-        elif os.environ.get("force_ansicolor","").lower() in ["false","no","n","0"] :
-            colored = False
-        _x_args.plain = not colored
+        _x_args.plain = colored
     if _x_args.keys_included :
         _xdt_keys_included = dict()
         for w in  _x_args.keys_included.split(",") :
@@ -510,7 +508,22 @@ def dsq_main():
             INPUT = INPUT.strip()
     else : 
         if not _x_args.interactive :
+            import signal
+            TIMEOUT = 1
+            def interrupted(signal, frame):
+                print("# timeout/no input from STDIN detected.",
+                      file=sys.stderr,
+                      flush=True)
+                parser.print_help()
+                sys.exit(0)
+        
+            try :
+                signal.signal(signal.SIGALRM, interrupted)
+                signal.alarm(TIMEOUT)
+            except :
+                pass
             INPUT = sys.stdin.read()
+            signal.alarm(0)
             INPUT = INPUT.strip()
     if not INPUT :
         INPUT = json.dumps({})
